@@ -1,5 +1,4 @@
 require 'test/unit'
-require_relative 'envutil'
 
 class TestEncoding < Test::Unit::TestCase
 
@@ -34,6 +33,9 @@ class TestEncoding < Test::Unit::TestCase
       assert_raise(TypeError) { e.dup }
       assert_raise(TypeError) { e.clone }
       assert_equal(e.object_id, Marshal.load(Marshal.dump(e)).object_id)
+      assert_not_predicate(e, :tainted?)
+      Marshal.load(Marshal.dump(e).taint)
+      assert_not_predicate(e, :tainted?, '[ruby-core:71793] [Bug #11760]')
     end
   end
 
@@ -107,6 +109,10 @@ class TestEncoding < Test::Unit::TestCase
     bin = "a".force_encoding(Encoding::ASCII_8BIT)
     asc = "b".force_encoding(Encoding::US_ASCII)
     assert_equal(Encoding::ASCII_8BIT, Encoding.compatible?(bin, asc))
+    bin = "\xff".force_encoding(Encoding::ASCII_8BIT).to_sym
+    asc = "b".force_encoding(Encoding::ASCII_8BIT)
+    assert_equal(Encoding::ASCII_8BIT, Encoding.compatible?(bin, asc))
+    assert_equal(Encoding::UTF_8, Encoding.compatible?("\u{3042}".to_sym, ua.to_sym))
   end
 
   def test_errinfo_after_autoload
